@@ -126,9 +126,6 @@ class Playlists(GObject.GObject):
         'song-removed-from-playlist': (
             GObject.SignalFlags.RUN_FIRST, None, (Grl.Media, Grl.Media)
         ),
-        'song-position-changed': (
-            GObject.SignalFlags.RUN_FIRST, None, (Grl.Media, Grl.Media)
-        ),
     }
 
     instance = None
@@ -164,7 +161,7 @@ class Playlists(GObject.GObject):
             try:
                 cursor.next_finish(res)
             except GLib.Error as err:
-                logger.warn("Error: %s, %s", err.__class__, err)
+                logger.warning("Error: {}, {}".format(err.__class__, err))
                 return
 
             playlist.ID = cursor.get_integer(1)
@@ -181,7 +178,7 @@ class Playlists(GObject.GObject):
             try:
                 cursor = obj.query_finish(result)
             except GLib.Error as err:
-                logger.warn("Error: %s, %s", err.__class__, err)
+                logger.warning("Error: {}, {}".format(err.__class__, err))
                 return
 
             # Search for the playlist ID
@@ -208,7 +205,7 @@ class Playlists(GObject.GObject):
             try:
                 cursor.next_finish(res)
             except GLib.Error as err:
-                logger.warn("Error: %s, %s", err.__class__, err)
+                logger.warning("Error: {}, {}".format(err.__class__, err))
                 return
 
             playlist.ID = cursor.get_integer(0)
@@ -221,7 +218,7 @@ class Playlists(GObject.GObject):
             try:
                 cursor = obj.query_finish(res)
             except GLib.Error as err:
-                logger.warn("Error: %s, %s", err.__class__, err)
+                logger.warning("Error: {}, {}".format(err.__class__, err))
                 return
 
             cursor.next_async(None, playlist_next_async_cb, playlist)
@@ -282,7 +279,7 @@ class Playlists(GObject.GObject):
         try:
             cursor = connection.query_finish(res)
         except GLib.Error as err:
-            logger.warn("Error: %s, %s", err.__class__, err)
+            logger.warning("Error: {}, {}".format(err.__class__, err))
             return
 
         def callback(cursor, res, final_query):
@@ -292,7 +289,7 @@ class Playlists(GObject.GObject):
             try:
                 has_next = cursor.next_finish(res)
             except GLib.Error as err:
-                logger.warn("Error: %s, %s", err.__class__, err)
+                logger.warning("Error: {}, {}".format(err.__class__, err))
                 has_next = False
 
             # Only perform the update when the cursor reached the end
@@ -324,7 +321,7 @@ class Playlists(GObject.GObject):
             try:
                 cursor.next_finish(res)
             except GLib.Error as err:
-                logger.warn("Error: %s, %s", err.__class__, err)
+                logger.warning("Error: {}, {}".format(err.__class__, err))
                 return
 
             playlist_id = cursor.get_integer(0)
@@ -334,7 +331,7 @@ class Playlists(GObject.GObject):
             try:
                 cursor = conn.query_finish(res)
             except GLib.Error as err:
-                logger.warn("Error: %s, %s", err.__class__, err)
+                logger.warning("Error: {}, {}".format(err.__class__, err))
                 return
 
             if not cursor:
@@ -441,7 +438,6 @@ class Playlists(GObject.GObject):
         """
         def update_callback(conn, res, data):
             conn.update_finish(res)
-            self.emit('song-position-changed', playlist, data)
 
         for item, new_position in zip(items, new_positions):
             self.tracker.update_async(
